==> haskell-sandwich-0.1.5.2-7-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-sandwich.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 sandwich
version:              0.1.5.2
visibility:           public
id:                   sandwich-0.1.5.2-3y6j0pNvdiv95XEr9HpuJT
key:                  sandwich-0.1.5.2-3y6j0pNvdiv95XEr9HpuJT
license:              BSD-3-Clause
copyright:            2023 Tom McLaughlin
maintainer:           tom@codedown.io
author:               Tom McLaughlin
homepage:             https://codedownio.github.io/sandwich
synopsis:             Yet another test framework for Haskell
description:
    Please see the <https://codedownio.github.io/sandwich documentation>.

category:             Testing
abi:                  f517c96710f4b8e7e1531b3770a0ec40
exposed:              True
exposed-modules:
    Test.Sandwich Test.Sandwich.Contexts Test.Sandwich.Expectations
    Test.Sandwich.Formatters.FailureReport
    Test.Sandwich.Formatters.LogSaver Test.Sandwich.Formatters.Print
    Test.Sandwich.Formatters.Silent Test.Sandwich.Formatters.TerminalUI
    Test.Sandwich.Golden Test.Sandwich.Internal Test.Sandwich.Logging
    Test.Sandwich.Misc Test.Sandwich.Nodes Test.Sandwich.Options
    Test.Sandwich.TH

hidden-modules:
    Test.Sandwich.ArgParsing Test.Sandwich.Formatters.Common.Count
    Test.Sandwich.Formatters.Common.Util
    Test.Sandwich.Formatters.MarkdownSummary
    Test.Sandwich.Formatters.Print.CallStacks
    Test.Sandwich.Formatters.Print.Color
    Test.Sandwich.Formatters.Print.Common
    Test.Sandwich.Formatters.Print.FailureReason
    Test.Sandwich.Formatters.Print.Logs
    Test.Sandwich.Formatters.Print.Printing
    Test.Sandwich.Formatters.Print.PrintPretty
    Test.Sandwich.Formatters.Print.Types
    Test.Sandwich.Formatters.Print.Util Test.Sandwich.Golden.Update
    Test.Sandwich.Internal.Formatters Test.Sandwich.Internal.Running
    Test.Sandwich.Interpreters.FilterTree
    Test.Sandwich.Interpreters.FilterTreeModule
    Test.Sandwich.Interpreters.PrettyShow
    Test.Sandwich.Interpreters.PruneTree
    Test.Sandwich.Interpreters.RunTree
    Test.Sandwich.Interpreters.RunTree.Logging
    Test.Sandwich.Interpreters.RunTree.Util
    Test.Sandwich.Interpreters.StartTree Test.Sandwich.ParallelN
    Test.Sandwich.RunTree Test.Sandwich.Shutdown Test.Sandwich.Signals
    Test.Sandwich.TestTimer Test.Sandwich.TH.HasMainFunction
    Test.Sandwich.TH.ModuleMap Test.Sandwich.Types.ArgParsing
    Test.Sandwich.Types.General Test.Sandwich.Types.RunTree
    Test.Sandwich.Types.Spec Test.Sandwich.Types.TestTimer
    Test.Sandwich.Types.TestTimer.LensRules Test.Sandwich.Util
    Paths_sandwich Test.Sandwich.Formatters.TerminalUI.AttrMap
    Test.Sandwich.Formatters.TerminalUI.CrossPlatform
    Test.Sandwich.Formatters.TerminalUI.Draw
    Test.Sandwich.Formatters.TerminalUI.Draw.ColorProgressBar
    Test.Sandwich.Formatters.TerminalUI.Draw.ToBrickWidget
    Test.Sandwich.Formatters.TerminalUI.Draw.TopBox
    Test.Sandwich.Formatters.TerminalUI.Draw.Util
    Test.Sandwich.Formatters.TerminalUI.Filter
    Test.Sandwich.Formatters.TerminalUI.Keys
    Test.Sandwich.Formatters.TerminalUI.OpenInEditor
    Test.Sandwich.Formatters.TerminalUI.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/sandwich-0.1.5.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/sandwich-0.1.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sandwich
hs-libraries:         HSsandwich-0.1.5.2-3y6j0pNvdiv95XEr9HpuJT
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr
    ansi-terminal-0.11.5-FgXvUwo3mIX2g72exyhUhE
    async-2.2.5-Hxx4nU8aNwh7V1GfZTZX85 base-4.16.4.0
    brick-1.7-4OkUY7YVpQ5GIBLUvkvTqY bytestring-0.11.4.0
    colour-2.3.6-HdI1cmU1Wok1ucyzh0SdSS containers-0.6.5.1
    deepseq-1.4.6.1 directory-1.3.6.2 exceptions-0.10.4
    filepath-1.4.2.2 free-5.1.10-GOblXT8Z2deK2DPOVW8Wt0
    haskell-src-exts-1.23.1-EQsaf5CMOxi6fZopto4Klc
    lifted-async-0.10.2.5-AGUcV76wxJN49mM3NYhUwU
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    microlens-th-0.4.3.15-BttKu46tg2TPgxEFeI4m6
    monad-control-1.0.3.1-I8GZevPHGG9CaaoPHICfGK
    monad-logger-0.3.40-2U6wkfWu2pa7AyH1VLvETa mtl-2.2.2
    optparse-applicative-0.17.1.0-AgMeQrX7nmlDOnX2xcegDb
    pretty-show-1.10-JwphvxEdk99BsHrT870tUy process-1.6.16.0
    safe-0.3.21-98IVtOx0Wmj8cqPHUtTkEF
    safe-exceptions-0.1.7.4-yGF8KbS5lSHGOL59YSfXx stm-2.5.0.2
    string-interpolate-0.3.4.0-L3A8dPESgaj35YtlRCcSdH
    template-haskell-2.18.0.0 text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 transformers-base-0.4.6-L226RdjYZ7s6DhRd0WmCwN
    unix-2.7.2.2 unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r
    vty-5.38-CaRMGIrplVnJIAnXF6jMgR

haddock-interfaces:   /usr/share/doc/haskell-sandwich/html/sandwich.haddock
haddock-html:         /usr/share/doc/haskell-sandwich/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sandwich-0.1.5.2-73.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-sandwich.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sandwich
version:              0.1.5.2
visibility:           public
id:                   sandwich-0.1.5.2-2DaRJ8uNkH9AIAMwYDZt1R
key:                  sandwich-0.1.5.2-2DaRJ8uNkH9AIAMwYDZt1R
license:              BSD-3-Clause
copyright:            2023 Tom McLaughlin
maintainer:           tom@codedown.io
author:               Tom McLaughlin
homepage:             https://codedownio.github.io/sandwich
synopsis:             Yet another test framework for Haskell
description:
    Please see the <https://codedownio.github.io/sandwich documentation>.

category:             Testing
abi:                  24d84d2cbb787b3c435234ba6f500685
exposed:              True
exposed-modules:
    Test.Sandwich Test.Sandwich.Contexts Test.Sandwich.Expectations
    Test.Sandwich.Formatters.FailureReport
    Test.Sandwich.Formatters.LogSaver Test.Sandwich.Formatters.Print
    Test.Sandwich.Formatters.Silent Test.Sandwich.Formatters.TerminalUI
    Test.Sandwich.Golden Test.Sandwich.Internal Test.Sandwich.Logging
    Test.Sandwich.Misc Test.Sandwich.Nodes Test.Sandwich.Options
    Test.Sandwich.TH

hidden-modules:
    Test.Sandwich.ArgParsing Test.Sandwich.Formatters.Common.Count
    Test.Sandwich.Formatters.Common.Util
    Test.Sandwich.Formatters.MarkdownSummary
    Test.Sandwich.Formatters.Print.CallStacks
    Test.Sandwich.Formatters.Print.Color
    Test.Sandwich.Formatters.Print.Common
    Test.Sandwich.Formatters.Print.FailureReason
    Test.Sandwich.Formatters.Print.Logs
    Test.Sandwich.Formatters.Print.Printing
    Test.Sandwich.Formatters.Print.PrintPretty
    Test.Sandwich.Formatters.Print.Types
    Test.Sandwich.Formatters.Print.Util Test.Sandwich.Golden.Update
    Test.Sandwich.Internal.Formatters Test.Sandwich.Internal.Running
    Test.Sandwich.Interpreters.FilterTree
    Test.Sandwich.Interpreters.FilterTreeModule
    Test.Sandwich.Interpreters.PrettyShow
    Test.Sandwich.Interpreters.PruneTree
    Test.Sandwich.Interpreters.RunTree
    Test.Sandwich.Interpreters.RunTree.Logging
    Test.Sandwich.Interpreters.RunTree.Util
    Test.Sandwich.Interpreters.StartTree Test.Sandwich.ParallelN
    Test.Sandwich.RunTree Test.Sandwich.Shutdown Test.Sandwich.Signals
    Test.Sandwich.TestTimer Test.Sandwich.TH.HasMainFunction
    Test.Sandwich.TH.ModuleMap Test.Sandwich.Types.ArgParsing
    Test.Sandwich.Types.General Test.Sandwich.Types.RunTree
    Test.Sandwich.Types.Spec Test.Sandwich.Types.TestTimer
    Test.Sandwich.Types.TestTimer.LensRules Test.Sandwich.Util
    Paths_sandwich Test.Sandwich.Formatters.TerminalUI.AttrMap
    Test.Sandwich.Formatters.TerminalUI.CrossPlatform
    Test.Sandwich.Formatters.TerminalUI.Draw
    Test.Sandwich.Formatters.TerminalUI.Draw.ColorProgressBar
    Test.Sandwich.Formatters.TerminalUI.Draw.ToBrickWidget
    Test.Sandwich.Formatters.TerminalUI.Draw.TopBox
    Test.Sandwich.Formatters.TerminalUI.Draw.Util
    Test.Sandwich.Formatters.TerminalUI.Filter
    Test.Sandwich.Formatters.TerminalUI.Keys
    Test.Sandwich.Formatters.TerminalUI.OpenInEditor
    Test.Sandwich.Formatters.TerminalUI.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/sandwich-0.1.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sandwich-0.1.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sandwich-0.1.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sandwich
hs-libraries:         HSsandwich-0.1.5.2-2DaRJ8uNkH9AIAMwYDZt1R
depends:
    aeson-2.1.2.1-38LADbNStwmEfKOReucTQy
    ansi-terminal-1.0.2-CHKNXEXhuZ3EvZtvAUncPO
    async-2.2.5-CjCuZi34HovIas1x5o0XNl base-4.17.2.1
    brick-1.9-HdhZm8hhO5g16g3F0hLdvV bytestring-0.11.5.3
    colour-2.3.6-EBRe8mBxzeqCy9m4vJD3mT containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 free-5.2-BmSPX9aY7BM8SWgWJCvikU
    haskell-src-exts-1.23.1-9EvhCcP56BSBlDpgj0lBcI
    lifted-async-0.10.2.7-CXsFodPCKOqAOABREez4pm
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    microlens-th-0.4.3.17-Vfga0HXPTS6SXD3NuXqZ3
    monad-control-1.0.3.1-CU0oSebqH0K53geyhZCKTM
    monad-logger-0.3.42-5hI1L1PwsnhGPBc3I2vfqe mtl-2.2.2
    optparse-applicative-0.17.1.0-3DJFXm9vTXK45PcUNAvg30
    pretty-show-1.10-Il8DKxKkDEW3pjtvdJ1ynD process-1.6.18.0
    safe-0.3.21-9t18UaHoT5jA6SQBJagYvS
    safe-exceptions-0.1.7.4-IOEkGTzCgP9nsdy3dwni1 stm-2.5.1.0
    string-interpolate-0.3.4.0-3pPvg9FpEjl2JaQftnXpLc
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-Gpx2WMc051hBRdn2HnKilA
    unix-2.7.3 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    vector-0.13.2.0-H3MTIE0bxkOEYwCD854O16
    vty-5.39-FkOoGDeVC3lFc2ATuhVqW8

haddock-interfaces:   /usr/share/doc/haskell-sandwich/html/sandwich.haddock
haddock-html:         /usr/share/doc/haskell-sandwich/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
